@@ -78,7 +78,7 @@ class GunicornLogger(Logger):
         atoms = self.atoms(resp, req, environ, request_time)
         atoms["t"] = str(datetime.utcnow())
         for k, value in atoms.items():
-            if '"' in value:
+            if isinstance(value, str) and '"' in value:
                 atoms[k] = value.replace('"', "'")
         safe_atoms = self.atoms_wrapper_class(atoms)
 
